/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file fileinfo.h
 *
 * @type helper
 *
 * @description
 *
 * The fileinfo helper is used to create a RISC OS style-guide compliant
 * file information box.
 */

#ifndef __rov_fileinfo
#define __rov_fileinfo


#ifdef __cplusplus
extern "C"
{
#endif

#ifndef __rov_main
#include "main.h"
#endif

/**
 * Creates a file information box.
 * @return the created canvas.
 * @note You can only create one file information box per application.
 * @see fileinfo_setup()
 */
canvas fileinfo_create(void);

/**
 * Populates the file information box with information about a file.
 * @param file_name the name of the file.
 * @param file_type the type of the file.
 * @param file_size the size of the file.
 * @param file_date the date of the file.
 * @param modified non-zero if the file has been modified.
 * @see file.h
 * @see fileinfo_create()
 */
void fileinfo_setup(char *file_name,
		    int file_type,
		    int file_size,
		    date_str *file_date,
		    BOOL modified);


#ifdef __cplusplus
}
#endif

#endif
